@@ -11,12 +11,13 @@ LogFormatter.apply()
 class MongoDB:
     
     """
-    Class for handling all the mongo related update, delete and fetching
+    MongoDB utility functions.
     """
     
     def __init__(self, db=None, uri=None):
         """
-        initialisation method for mongo adaptor
+        initialisation method for MongoDB connector
+        :param str db: database name
         :param str uri: mongo uri string for establishing connection
         """
 
@@ -38,7 +39,8 @@ class MongoDB:
         Function for inserting data into db
         :param str db : database name
         :param str collection : collection name
-        :param list/pd.DataFrame : data to be inserted and it should be either dataframe or list of dictionaries
+        :param list/pd.DataFrame data : data to be inserted in the form of dataframe or list of dictionaries
+        :return:
         """
         
         if db==None:
@@ -62,6 +64,13 @@ class MongoDB:
                 self.client = MongoClient(self.uri)
 
     def pull_data(self, list_dict, collection, db=None):
+        """
+        Function for inserting data into db
+        :param str db : database name
+        :param str collection : collection name
+        :param list list_dict : query for fetching data
+        :return: pd.DataFrame 
+        """
         
         if db==None:
             db = self.db
@@ -90,6 +99,16 @@ class MongoDB:
                 self.client = MongoClient(self.uri)
                 
     def update_value(self, id_dict, set_dict, collection, db=None, upsert=None):
+
+        """
+        Function for updating data into db
+        :param str db : database name
+        :param str collection : collection name
+        :param dict id_dict : query for updation
+        :param dict set_dict : key and value dictionary to be updated
+        :param bool upsert : whether to upsert or just update
+        :return:
+        """
         
         if db==None:
             db = self.db
@@ -109,6 +128,15 @@ class MongoDB:
                 self.client = MongoClient(self.uri)
                 
     def upsert_json(self, output_json, upsert_keys, collection, db=None):
+
+        """
+        Function for inserting data into db
+        :param str db : database name
+        :param str collection : collection name
+        :param dict output_json : list of dictionaries where each dictionary is a row with keys as column names
+        :param list upsert_keys : keys to be upserted
+        :return:
+        """
         
         if db==None:
             db = self.db
@@ -133,6 +161,15 @@ class MongoDB:
 
 
     def delete_data(self,collection, db=None, overall=False, condition_dict=None):
+
+        """
+        Function for inserting data into db
+        :param str db : database name
+        :param str collection : collection name
+        :param bool overall : delete whole collection if True
+        :param dict condition_dict : query for deletion
+        :return: 
+        """
         
         if db==None:
             db = self.db
@@ -158,11 +195,11 @@ class MongoDB:
     def fetch_data(self, collection, db=None, query={}, only_include_keys=[]):
         """
         function to fetch data from the given database and collection on given query
-        :param db: db_name in mongo
-        :param collection: collection name in mongo for database db
-        :param query: execution query statement; default is {} which means fetch all without any filters
-        :param only_include_keys: list of keys to be included while fetching rows
-        :return:
+        :param str db: db_name in mongo
+        :param str collection: collection name in mongo for database db
+        :param dict query: execution query statement; default is {} which means fetch all without any filters
+        :param list only_include_keys: list of keys to be included while fetching rows
+        :return: pd.DataFrame 
         """
         if db==None:
             db = self.db
@@ -195,10 +232,10 @@ class MongoDB:
     def fetch_data_sorted(self, collection, db=None, pipeline=[]):
         """
         function to fetch data from the given database and collection on given query
-        :param db: db_name in mongo
-        :param collection: collection name in mongo for database db
-        :param pipeline: pipeline required to aggregate
-        :return:
+        :param str db: db_name in mongo
+        :param str collection: collection name in mongo for database db
+        :param list pipeline: pipeline required to aggregate
+        :return: pd.DataFrame 
         """
         
         if db==None:
